aboutsummaryrefslogtreecommitdiff
path: root/ldcg-python-manylinux-tensorflow/build-manylinux2014-wheels.sh
diff options
context:
space:
mode:
Diffstat (limited to 'ldcg-python-manylinux-tensorflow/build-manylinux2014-wheels.sh')
-rw-r--r--ldcg-python-manylinux-tensorflow/build-manylinux2014-wheels.sh11
1 files changed, 5 insertions, 6 deletions
diff --git a/ldcg-python-manylinux-tensorflow/build-manylinux2014-wheels.sh b/ldcg-python-manylinux-tensorflow/build-manylinux2014-wheels.sh
index 07c9d5c53b..2c85328bae 100644
--- a/ldcg-python-manylinux-tensorflow/build-manylinux2014-wheels.sh
+++ b/ldcg-python-manylinux-tensorflow/build-manylinux2014-wheels.sh
@@ -3,16 +3,15 @@
set -xe
# Ansible is noarch so we can just grab it from x86-64 repo
-yum install -y http://mirror.centos.org/centos/7/configmanagement/x86_64/ansible-29/Packages/a/ansible-2.9.18-1.el7.noarch.rpm
+yum install -y centos-release-ansible-29
+yum install -y ansible
cd /tmp/workspace
# remove wheels and wheelhouse/ from previous jobs
# we do it here as they are root:root
-rm -rf wheel* *.whl cache* configs
+rm -rf wheels *.whl cache* venv-* tensorflow-* || true
-git clone --depth 1 https://git.linaro.org/ci/job/configs.git
-
cd configs/ldcg-python-manylinux-tensorflow/ansible
-
+
ansible-playbook playbooks/build-tf.yml
@@ -3,16 +3,15 @@
cd /tmp/workspace
-# remove wheels and wheelhouse/ from previous jobs
+# remove tensorflow source, wheels and venvs from previous jobs
# we do it here as they are root:root